import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import Text from './Text'

const getStyle = ({ primary, secondary, danger }, theme) => {
  let intent

  if (primary) intent = theme.intent.primary
  if (secondary) intent = theme.intent.secondary
  if (danger) intent = theme.intent.danger

  if (!intent) return ''

  return `
    color: ${intent.default.linkColor};

    &:hover {
      color: ${intent.hover.linkColor};
    }

    &:focus {
      color: ${intent.focus.linkColor};
    }

    &:active,
    &.active {
      color: ${intent.active.linkColor};
    }
  `
}

const styles = ({
  underline,
  primary,
  secondary,
  danger,
  naked,
  theme
}) => css`
  text-decoration: ${underline ? `underline` : `none`};
  transition: 120ms;
  transition-property: background-color, color, box-shadow, opacity;

  ${getStyle({ primary, secondary, danger, naked }, theme)}

  &:active,
  &:focus {
    outline: none;
  }
`

const parseProps = ({ active, className, ...props }) => {
  const newClassName = active ? `${className} active` : className
  return { className: newClassName, is: active ? 'span' : 'a', ...props }
}

const Link = styled(({ primary, secondary, danger, naked, ...props }) =>
  React.createElement(Text, parseProps(props)))`${styles}`

Link.propTypes = {
  ...Text.propTypes,
  underline: PropTypes.bool,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  active: PropTypes.bool
}

Link.displayName = 'Link'

export default Link
